export default {
  title: 'Info',

  componentProps: [
    {
      name: 'published',
      type: 'string',
      description: 'A parseable datestring signifying the date and time it was published',
    },
    {
      name: 'updated',
      type: 'string',
      description: 'A parseable datestring signifying the date and time it was last updated',
    },
    {
      name: 'defaultTimezone',
      type: 'string',
      default: 'America/New_York',
      description: 'A valid tz database timezone name to use as the default timezone if your user\'s timezone cannot be determined',
    },
    {
      name: 'authors',
      type: 'Author[]',
      description: 'An array of author objects (see below)',
    },
    {
      name: 'Author',
      type: 'object',
      description: `Information about a particular author (used in 'authors' props)`,
    },
    {
      name: 'Author.name',
      type: 'string',
      description: `The author's name (used in 'Author' object)`,
    },
    {
      name: 'Author.link',
      type: 'string',
      description: `A link to the author's bio (used in 'Author' object)`,
    },
  ],

  cssProps: [
    {
      name: 'root',
      globalClass: 'PibInfo-root',
      description: 'Styles applied to root element',
    },
    {
      name: 'container',
      globalClass: 'PibInfo-container',
      description: 'Styles applied to container element',
    },
    {
      name: 'authorsContainer',
      globalClass: 'PibInfo-authors',
      description: 'Styles applied to bylines container element',
    },
    {
      name: 'published',
      globalClass: 'PibInfo-published',
      description: 'Styles applied to published dateline',
    },
    {
      name: 'updated',
      globalClass: 'PibInfo-updated',
      description: 'Styles applied to updated dateline',
    },
    {
      name: 'timestamp',
      globalClass: 'PibInfo-timestamp',
      description: 'Styles applied to timestamp element',
    },
  ],

  examples: [
    {
      code: `
<Info
  authors={[
    {
      link: 'https://politico.com',
      name: 'First Lastname',
    },
  ]}
  published = {new Date('January 1, 1970 9:00:00').toISOString()}
  updated = {null}
/>`,
    },
    {
      name: 'Multiple Authors',
      description: 'Add another object to the "authors" props with a "link" and "name" to add another author. The component will concatenate all the names with proper english syntax. Try adding or removing names to see it work.',
      code: `
<Info
  authors={[
    {
      link: 'https://politico.com',
      name: 'Andrew Briz',
    },
    {
      link: 'https://politico.com',
      name: 'Beatrice Jin',
    },
    {
      link: 'https://politico.com',
      name: 'Lily Mihalik',
    },
  ]}
  published = {null}
  updated = {null}
/>`,
    },
    {
      name: 'Published and Updated Times',
      description: 'If you have an updated time, set the "updated" prop. Note that this will move the "<time />" element to reflect the updated time instead of the published time. Inspect the element below to see that.',
      code: `
<Info
  authors={[
    {
      link: 'https://politico.com',
      name: 'First Lastname',
    },
  ]}
  published = {new Date('January 1, 1970 9:00:00').toISOString()}
  updated = {new Date('January 3, 1970 13:00:00').toISOString()}
/>`,
    },
    {
      name: 'Time Zones',
      description: 'This component will do its best to display published and updated dates in the user\'s local time. For SSR reasons though (or if the user\'s timezone cannot be determined) there has to be a default timezone. As an EST based-publication, we default to that, but you can override this default if you\'d like. If you view this page\'s source code you\'ll see that the timestamp below is in PST time. Note that the date provided must ALWAYS be provided in EST time.',
      code: `
<Info
  authors={[
    {
      link: 'https://politico.com',
      name: 'First Lastname',
    },
  ]}
  defaultTimezone = "America/Los_Angeles"
  published = {new Date('January 1, 1970 9:00:00').toISOString()}
  updated = {new Date('January 3, 1970 13:00:00').toISOString()}
/>`,
    },
  ],
};
