export default {
  title: 'Share',

  componentProps: [
    {
      name: 'subject',
      type: 'string',
      description: 'The subject line to use in emails',
    },
    {
      name: 'body',
      type: 'string',
      description: 'The body to use in emails and Tweets',
    },
    {
      name: 'onFb',
      type: 'function',
      description: 'Click handler for clicking the Facebook share button',
    },
    {
      name: 'onTwitter',
      type: 'function',
      description: 'Click handler for clicking the Twitter share button',
    },
    {
      name: 'onMail',
      type: 'function',
      description: 'Click handler for clicking the mail button',
    },
  ],

  cssProps: [
    {
      name: 'root',
      globalClass: 'PibShare-root',
      description: 'Styles applied to root div',
    },
    {
      name: 'button',
      globalClass: 'PibShare-button',
      description: 'Styles applied to each button',
    },
  ],

  examples: [
    {
      code: `

<Share
  subject="POLITICO: Story Headline For E-Mail"
  body="Story Headline For Share Tweet"
/>

`,
    },
    {
      name: 'Email/Tweet Text',
      description: 'You can set the default text for an email or tweet when a user clicks the button. "Body" will be used for email bodies and Tweet texts. "Subject" will be used for email subject lines. Try changing the text in the code and clicking the button to see it take effect.',
      code: `
<Share
  subject="TK Subject TK"
  body="TK Body Tk"
/>
    `,
    },
    {
      name: 'Custom Click Handlers',
      description: 'You can pass custom click handlers for each event. Note that handlers fire before the usual before takes place (i.e. the alert will fire before the Twitter share link opens). Try clicking a button to see the handler fire.',
      code: `
<Share
  subject="TK Subject TK"
  body="TK Body Tk"
  onFb={() => {alert('You clicked FaceBook!')}}
  onTwitter={() => {alert('You clicked Twitter!')}}
  onMail={() => {alert('You clicked Mail!')}}
/>
    `,
    },
  ],
};
