import { createElement, useMemo } from 'react';
import classnames from 'classnames';
import assign from 'lodash/assign';
import omit from 'lodash/omit';
import ReactMarkdown from 'react-markdown/with-html';

import stylesheet from './styles.module.scss';

const BaseTypography = (props) => {
  const { type, children, classes, bolder, lighter, sans } = props;
  const { container: containerClass, text: textClass } = classes;

  const childProps = useMemo(() => {
    const classes = classnames('PibTypography-text', textClass, {
      bolder,
      lighter,
      sans: sans || props['sans-serif'],
      'no-margins': props['no-margins'],
    });

    return assign(
      omit(
        props,
        [
          'type',
          'children',
          'className',
          'bolder',
          'lighter',
          'sans',
          'sans-serif',
          'classes',
          'no-margins',
        ]),
      {
        className: classes,
      }
    );
  }, [props]);

  return (
    <div className={classnames('PibTypography-container', containerClass)}>
      {createElement(
        type,
        childProps,
        children
      )}
      <style jsx>{stylesheet}</style>
    </div>
  );
};

BaseTypography.defaultProps = {
  type: 'p',
  lighter: false,
  bolder: false,
  sans: false,
  'sans-serif': false,
  'no-margins': false,
  classes: {
    container: '',
    text: '',
  },
};

export { BaseTypography };

export const H1 = props => {
  return (
    <BaseTypography {...props} type='h1' />
  );
};

export const H2 = props => {
  return (
    <BaseTypography {...props} type='h2' />
  );
};

export const H3 = props => {
  return (
    <BaseTypography {...props} type='h3' />
  );
};

export const H4 = props => {
  return (
    <BaseTypography {...props} type='h4' />
  );
};

export const H5 = props => {
  return (
    <BaseTypography {...props} type='h5' />
  );
};

export const H6 = props => {
  return (
    <BaseTypography {...props} type='h6' />
  );
};

export const P = props => {
  return (
    <BaseTypography {...props} type='p' />
  );
};

export const Markdown = props => {
  return (
    <BaseTypography {...props} type='div'>
      <div className='testing' />
      <ReactMarkdown {...props.markdownProps} source={props.children} />
    </BaseTypography>
  );
};

export default {
  Base: BaseTypography,
  H1,
  H2,
  H3,
  H4,
  H5,
  H6,
  P,
  Markdown,
};
