import React from 'react';
import Highlight, { defaultProps } from 'prism-react-renderer';

import copy from 'copy-to-clipboard';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faCopy } from '@fortawesome/free-solid-svg-icons';

import theme from 'Components/common/themes/a11y-dark';
import stylesheet from './styles.module.scss';

const CodeBlock = props => {
  const { children: code } = props;

  return (
    <div className='code-block'>
      <div className='action-bar'>
        <button
          className='copy action-button'
          onClick={() => copy(code)}
        >
          <FontAwesomeIcon icon={faCopy} />
        </button>
      </div>
      <Highlight {...defaultProps} code={code} theme={theme} language='jsx'>
        {({ className, style, tokens, getLineProps, getTokenProps }) => (
          <pre className={className} style={style}>
            {tokens.map((line, i) => (
              <div key={i} {...getLineProps({ line, key: i })}>
                {line.map((token, key) => (
                  <span key={key} {...getTokenProps({ token, key })} />
                ))}
              </div>
            ))}
          </pre>
        )}
      </Highlight>
      <style jsx>{stylesheet}</style>
    </div>
  );
};

export default CodeBlock;
