import { Element } from 'react-scroll';

import stylesheet from './styles.module.scss';

const PropsBlock = props => {
  const { componentProps } = props;

  if (componentProps.length === 0) {
    return null;
  }

  return (
    <div className='props-block'>
      <Element name='Props' />
      <h2>Props</h2>
      <table>
        <thead>
          <tr>
            <th className='name-header'>Name</th>
            <th className='type-header'>Type</th>
            <th className='default-header'>Default</th>
            <th className='description-header'>Description</th>
          </tr>
        </thead>
        <tbody>
          {componentProps.map(p =>
            <tr key={p.name}>
              <td><span className='name'>{p.name}</span></td>
              <td>
                <span className='type'>
                  {
                    Array.isArray(p.type) ?
                      p.type.map(choice =>
                        <span key={choice} className='type-choice'>
                          {choice}
                        </span>
                      ) :
                      p.type
                  }
                </span>
              </td>
              <td><span className='default'>{p.default}</span></td>
              <td><span className='description'>{p.description}</span></td>
            </tr>
          )}
        </tbody>
      </table>
      <style jsx>{stylesheet}</style>
    </div>
  );
};

PropsBlock.defaultProps = {
  componentProps: [],
};

export default PropsBlock;
