import ImportBlock from './ImportBlock';
import PropsBlock from './PropsBlock';
import CssBlock from './CssBlock';
import Sandbox from '../Sandbox';

import * as components from '../../index';

import stylesheet from './styles.module.scss';

const Page = props => {
  const { title, description, examples } = props;

  return (
    <section className='section well'>
      <div className='container'>
        <div className='title'>
          <h1>{title}</h1>
        </div>

        <div className='description'>
          {description}
        </div>

        <Sandbox example={examples[0]} scope={components} />

        <ImportBlock {...props} scope={components} />

        <PropsBlock {...props} />

        <CssBlock {...props} />

        {examples.length > 1 &&
          <div className='demo-block'>
            <h2 className='quicksand'>Demos</h2>
            {examples.slice(1, examples.length).map(e =>
              <Sandbox key={e.code} example={e} scope={components} />
            )}
          </div>
        }

      </div>
      <style jsx>{stylesheet}</style>
    </section>
  );
};

Page.defaultProps = {
  link: '../',
  title: '',
};

export default Page;
