import classnames from 'classnames';
import { Element } from 'react-scroll';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faCopy } from '@fortawesome/free-solid-svg-icons';
import copy from 'copy-to-clipboard';

import stylesheet from './styles.module.scss';

const VarTable = props => {
  const getName = v => {
    return props.isVar ? `$${v}` : v;
  };

  const copyName = v => () => {
    copy(getName(v));
  };

  return (
    <div className='var-table'>
      <Element name={props.name} />
      <h2 className='quicksand'>{props.name}</h2>
      <table>
        <thead>
          <tr>
            <th className='name-header'>Name</th>
            <th className='value-header'>Value</th>
          </tr>
        </thead>
        <tbody>
          {props.entries.map(p =>
            <tr key={p.name}>
              <td className='name-container' onClick={copyName(p.name)}>
                <span className='name'>{getName(p.name)}</span>
                <FontAwesomeIcon icon={faCopy} />
              </td>
              <td>
                <span className={classnames('value', { code: props.isCode })}>{p.value}</span>
              </td>
            </tr>
          )}
        </tbody>
      </table>
      <style jsx>{stylesheet}</style>
    </div>
  );
};

export default VarTable;
